@@ -36,6 +36,21 @@ def clean_before_kill(signum, stack):
     exit()
 
 
+def _last_line(input, as_a=int):
+    """Get the last line from given bytes
+
+    TODO - Pull it to utils if needed elsewhere in the future.
+    """
+    lines = list(
+        filter(
+            lambda x: x, [
+                x.strip().decode() for x in input.split(bytes(os.linesep, 'utf8'))
+            ]
+        )
+    )
+    return as_a(lines[-1])
+
+
 # as per https://docs.python.org/3.6/library/signal.html#signals-and-threads
 # only the main thread is allowed to set a new signal handler.
 # This means that if this module is imported by a thread other than the
@@ -146,15 +161,13 @@ class Mongod:
         ]
         try:
             logger.debug("Getting status")
-            uptime = subprocess.check_output(healthcheck)
+            uptime = _last_line(subprocess.check_output(healthcheck))
         except subprocess.CalledProcessError:
             logger.debug("Status: Not running")
             return False
         else:
-            if int(uptime) > 0:
-                logger.debug("Status: Running for {up} secs".format(
-                    up=str(uptime.decode()).strip()
-                ))
+            if uptime > 0:
+                logger.debug("Status: Running for {} secs".format(uptime))
                 return True
             else:
                 logger.debug("Status: Just started.")
